@@ -149,6 +149,9 @@ static gint gtk_image_draw                 (GtkWidget    *widget,
 static void gtk_image_unmap                (GtkWidget    *widget);
 static void gtk_image_realize              (GtkWidget    *widget);
 static void gtk_image_unrealize            (GtkWidget    *widget);
+static void gtk_image_get_preferred_size   (GtkImage     *image,
+                                            gint         *width_out,
+                                            gint         *height_out);
 static void gtk_image_get_preferred_width  (GtkWidget    *widget,
                                             gint         *minimum,
                                             gint         *natural);
@@ -921,19 +924,13 @@ gtk_image_set_from_file   (GtkImage    *image,
   GtkImagePrivate *priv;
   GdkPixbufAnimation *anim;
   gint scale_factor;
-  gint old_width, old_height;
-  gint new_width, new_height;
-  GtkStyleContext *context;
-
+  
   g_return_if_fail (GTK_IS_IMAGE (image));
 
   priv = image->priv;
 
   g_object_freeze_notify (G_OBJECT (image));
 
-  context = gtk_widget_get_style_context (GTK_WIDGET (image));
-  _gtk_icon_helper_get_size (priv->icon_helper, context, &old_width, &old_height);
-
   gtk_image_reset (image);
 
   if (filename == NULL)
@@ -969,15 +966,20 @@ gtk_image_set_from_file   (GtkImage    *image,
 
   priv->filename = g_strdup (filename);
 
-  _gtk_icon_helper_get_size (priv->icon_helper, context, &new_width, &new_height);
   if (gtk_widget_get_visible (GTK_WIDGET (image)))
     {
-      if (old_width != new_width || old_height != new_height)
+      gint width, height;
+
+      gtk_image_get_preferred_size (image, &width, &height);
+      if (width != gtk_widget_get_allocated_width (GTK_WIDGET (image)) ||
+          height != gtk_widget_get_allocated_height (GTK_WIDGET (image)))
         gtk_widget_queue_resize (GTK_WIDGET (image));
       else
         gtk_widget_queue_draw (GTK_WIDGET (image));
     }
 
+  g_object_notify (G_OBJECT (image), "file");
+
   g_object_thaw_notify (G_OBJECT (image));
 }
 
@@ -1048,9 +1050,6 @@ gtk_image_set_from_pixbuf (GtkImage  *image,
                            GdkPixbuf *pixbuf)
 {
   GtkImagePrivate *priv;
-  gint old_width, old_height;
-  gint new_width, new_height;
-  GtkStyleContext *context;
 
   g_return_if_fail (GTK_IS_IMAGE (image));
   g_return_if_fail (pixbuf == NULL || GDK_IS_PIXBUF (pixbuf));
@@ -1059,25 +1058,25 @@ gtk_image_set_from_pixbuf (GtkImage  *image,
 
   g_object_freeze_notify (G_OBJECT (image));
 
-  context = gtk_widget_get_style_context (GTK_WIDGET (image));
-  _gtk_icon_helper_get_size (priv->icon_helper, context, &old_width, &old_height);
-
   gtk_image_reset (image);
 
   if (pixbuf != NULL)
     _gtk_icon_helper_set_pixbuf (priv->icon_helper, pixbuf);
 
-  _gtk_icon_helper_get_size (priv->icon_helper, context, &new_width, &new_height);
   if (gtk_widget_get_visible (GTK_WIDGET (image)))
     {
-      if (old_width != new_width || old_height != new_height)
+      gint width, height;
+
+      gtk_image_get_preferred_size (image, &width, &height);
+      if (width != gtk_widget_get_allocated_width (GTK_WIDGET (image)) ||
+          height != gtk_widget_get_allocated_height (GTK_WIDGET (image)))
         gtk_widget_queue_resize (GTK_WIDGET (image));
       else
         gtk_widget_queue_draw (GTK_WIDGET (image));
     }
 
   g_object_notify (G_OBJECT (image), "pixbuf");
-
+  
   g_object_thaw_notify (G_OBJECT (image));
 }
 
@@ -1177,9 +1176,6 @@ gtk_image_set_from_animation (GtkImage           *image,
                               GdkPixbufAnimation *animation)
 {
   GtkImagePrivate *priv;
-  gint old_width, old_height;
-  gint new_width, new_height;
-  GtkStyleContext *context;
 
   g_return_if_fail (GTK_IS_IMAGE (image));
   g_return_if_fail (animation == NULL ||
@@ -1192,9 +1188,6 @@ gtk_image_set_from_animation (GtkImage           *image,
   if (animation)
     g_object_ref (animation);
 
-  context = gtk_widget_get_style_context (GTK_WIDGET (image));
-  _gtk_icon_helper_get_size (priv->icon_helper, context, &old_width, &old_height);
-
   gtk_image_reset (image);
 
   if (animation != NULL)
@@ -1203,17 +1196,20 @@ gtk_image_set_from_animation (GtkImage           *image,
       g_object_unref (animation);
     }
 
-  g_object_notify (G_OBJECT (image), "pixbuf-animation");
-
-  _gtk_icon_helper_get_size (priv->icon_helper, context, &new_width, &new_height);
   if (gtk_widget_get_visible (GTK_WIDGET (image)))
     {
-      if (old_width != new_width || old_height != new_height)
+      gint width, height;
+
+      gtk_image_get_preferred_size (image, &width, &height);
+      if (width != gtk_widget_get_allocated_width (GTK_WIDGET (image)) ||
+          height != gtk_widget_get_allocated_height (GTK_WIDGET (image)))
         gtk_widget_queue_resize (GTK_WIDGET (image));
       else
         gtk_widget_queue_draw (GTK_WIDGET (image));
     }
 
+  g_object_notify (G_OBJECT (image), "pixbuf-animation");
+  
   g_object_thaw_notify (G_OBJECT (image));
 }
 
@@ -1234,9 +1230,6 @@ gtk_image_set_from_icon_name  (GtkImage       *image,
 {
   GtkImagePrivate *priv;
   gchar *new_name;
-  gint old_width, old_height;
-  gint new_width, new_height;
-  GtkStyleContext *context;
 
   g_return_if_fail (GTK_IS_IMAGE (image));
 
@@ -1246,9 +1239,6 @@ gtk_image_set_from_icon_name  (GtkImage       *image,
 
   new_name = g_strdup (icon_name);
 
-  context = gtk_widget_get_style_context (GTK_WIDGET (image));
-  _gtk_icon_helper_get_size (priv->icon_helper, context, &old_width, &old_height);
-
   gtk_image_reset (image);
 
   if (new_name)
@@ -1257,18 +1247,21 @@ gtk_image_set_from_icon_name  (GtkImage       *image,
       g_free (new_name);
     }
 
-  g_object_notify (G_OBJECT (image), "icon-name");
-  g_object_notify (G_OBJECT (image), "icon-size");
-
-  _gtk_icon_helper_get_size (priv->icon_helper, context, &new_width, &new_height);
   if (gtk_widget_get_visible (GTK_WIDGET (image)))
     {
-      if (old_width != new_width || old_height != new_height)
+      gint width, height;
+
+      gtk_image_get_preferred_size (image, &width, &height);
+      if (width != gtk_widget_get_allocated_width (GTK_WIDGET (image)) ||
+          height != gtk_widget_get_allocated_height (GTK_WIDGET (image)))
         gtk_widget_queue_resize (GTK_WIDGET (image));
       else
         gtk_widget_queue_draw (GTK_WIDGET (image));
     }
 
+  g_object_notify (G_OBJECT (image), "icon-name");
+  g_object_notify (G_OBJECT (image), "icon-size");
+  
   g_object_thaw_notify (G_OBJECT (image));
 }
 
@@ -1288,9 +1281,6 @@ gtk_image_set_from_gicon  (GtkImage       *image,
 			   GtkIconSize     size)
 {
   GtkImagePrivate *priv;
-  gint old_width, old_height;
-  gint new_width, new_height;
-  GtkStyleContext *context;
 
   g_return_if_fail (GTK_IS_IMAGE (image));
 
@@ -1301,9 +1291,6 @@ gtk_image_set_from_gicon  (GtkImage       *image,
   if (icon)
     g_object_ref (icon);
 
-  context = gtk_widget_get_style_context (GTK_WIDGET (image));
-  _gtk_icon_helper_get_size (priv->icon_helper, context, &old_width, &old_height);
-
   gtk_image_reset (image);
 
   if (icon)
@@ -1312,18 +1299,21 @@ gtk_image_set_from_gicon  (GtkImage       *image,
       g_object_unref (icon);
     }
 
-  g_object_notify (G_OBJECT (image), "gicon");
-  g_object_notify (G_OBJECT (image), "icon-size");
-
-  _gtk_icon_helper_get_size (priv->icon_helper, context, &new_width, &new_height);
   if (gtk_widget_get_visible (GTK_WIDGET (image)))
     {
-      if (old_width != new_width || old_height != new_height)
+      gint width, height;
+
+      gtk_image_get_preferred_size (image, &width, &height);
+      if (width != gtk_widget_get_allocated_width (GTK_WIDGET (image)) ||
+          height != gtk_widget_get_allocated_height (GTK_WIDGET (image)))
         gtk_widget_queue_resize (GTK_WIDGET (image));
       else
         gtk_widget_queue_draw (GTK_WIDGET (image));
     }
 
+  g_object_notify (G_OBJECT (image), "gicon");
+  g_object_notify (G_OBJECT (image), "icon-size");
+  
   g_object_thaw_notify (G_OBJECT (image));
 }
 
@@ -1341,9 +1331,6 @@ gtk_image_set_from_surface (GtkImage       *image,
 			    cairo_surface_t *surface)
 {
   GtkImagePrivate *priv;
-  gint old_width, old_height;
-  gint new_width, new_height;
-  GtkStyleContext *context;
 
   g_return_if_fail (GTK_IS_IMAGE (image));
 
@@ -1354,9 +1341,6 @@ gtk_image_set_from_surface (GtkImage       *image,
   if (surface)
     cairo_surface_reference (surface);
 
-  context = gtk_widget_get_style_context (GTK_WIDGET (image));
-  _gtk_icon_helper_get_size (priv->icon_helper, context, &old_width, &old_height);
-
   gtk_image_reset (image);
 
   if (surface)
@@ -1365,17 +1349,20 @@ gtk_image_set_from_surface (GtkImage       *image,
       cairo_surface_destroy (surface);
     }
 
-  g_object_notify (G_OBJECT (image), "surface");
-
-  _gtk_icon_helper_get_size (priv->icon_helper, context, &new_width, &new_height);
   if (gtk_widget_get_visible (GTK_WIDGET (image)))
     {
-      if (old_width != new_width || old_height != new_height)
+      gint width, height;
+
+      gtk_image_get_preferred_size (image, &width, &height);
+      if (width != gtk_widget_get_allocated_width (GTK_WIDGET (image)) ||
+          height != gtk_widget_get_allocated_height (GTK_WIDGET (image)))
         gtk_widget_queue_resize (GTK_WIDGET (image));
       else
         gtk_widget_queue_draw (GTK_WIDGET (image));
     }
 
+  g_object_notify (G_OBJECT (image), "surface");
+  
   g_object_thaw_notify (G_OBJECT (image));
 }
 
