@@ -34,6 +34,7 @@
 #include "gtksizerequest.h"
 #include "gtkstylecontext.h"
 #include "gtkwindowprivate.h"
+#include "gtkaccessible.h"
 
 
 #ifdef GDK_WINDOWING_WAYLAND
@@ -166,6 +167,7 @@ gtk_tooltip_init (GtkTooltip *tooltip)
   GtkWidget *box;
   GtkWidget *image;
   GtkWidget *label;
+  AtkObject *atk_obj;
 
   tooltip->timeout_id = 0;
   tooltip->browse_mode_timeout_id = 0;
@@ -191,6 +193,10 @@ gtk_tooltip_init (GtkTooltip *tooltip)
   context = gtk_widget_get_style_context (window);
   gtk_style_context_add_class (context, GTK_STYLE_CLASS_TOOLTIP);
 
+  atk_obj = gtk_widget_get_accessible (window);
+  if (GTK_IS_ACCESSIBLE (atk_obj))
+    atk_object_set_role (atk_obj, ATK_ROLE_TOOL_TIP);
+
   /* FIXME: don't hardcode the padding */
   box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
   gtk_widget_set_margin_start (box, 6);
@@ -894,7 +900,7 @@ gtk_tooltip_set_last_window (GtkTooltip *tooltip,
 
   tooltip->last_window = window;
 
-  if (window)
+  if (tooltip->last_window)
     g_object_add_weak_pointer (G_OBJECT (tooltip->last_window),
 			       (gpointer *) &tooltip->last_window);
 
