@@ -12,9 +12,7 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <gtk/gtk.h>
@@ -49,7 +47,6 @@ spin_ythickness_cb (GtkSpinButton *spin, gpointer user_data)
   gtk_css_provider_load_from_data (provider, data, -1, NULL);
   g_free (data);
 
-  gtk_style_context_invalidate (context);
   gtk_widget_queue_resize (frame);
 }
 
@@ -82,7 +79,6 @@ spin_xthickness_cb (GtkSpinButton *spin, gpointer user_data)
   gtk_css_provider_load_from_data (provider, data, -1, NULL);
   g_free (data);
 
-  gtk_style_context_invalidate (context);
   gtk_widget_queue_resize (frame);
 }
 
